<?php
session_start();

// Check if the user is logged in
if (!isset($_SESSION['loggedin']) || $_SESSION['loggedin'] !== true) {
    header('Location: login.php'); // Redirect to the login page if not logged in
    exit;
}
?>


<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>API Usage Details</title>
    <link rel="stylesheet" href="style.css?v=0.1" />
    <style>
        #usageTable {
            width: 100%;
            border-collapse: collapse;
            margin-top: 5px;
        }
        #usageTable th, #usageTable td {
            border: 1px solid black;
            padding: 1px;
            text-align: center;
        }
        #usageTable th {
            background-color: #f2f2f2;
        }
        .api-key-button {
            border: none;
            padding: 1px 1px;
            font-size: 12px;
            margin-bottom: 1px;
            cursor: pointer;
            background-color: #007bff;
            color: #fff;
        }
        .voice-list {
            margin-top: 1px;
            padding: 1px;
            border: 1px solid black;
            background-color: #f9f9f9;
        }
        .voice-list select {
            width: 100%;
            padding: 1px;
            border: 1px solid black;
        }
    </style>
</head>
<body>
    <div id="voiceContainer" class="hidden">
        <h3>Available Voices</h3>
        <div id="voiceListContainer" class="voice-list">
            <select id="narrator-select"></select>
        </div>
    </div>

    <div id="usageTableContainer">
        <h3>All API Usage Details</h3>
        <table id="usageTable">
            <thead>
                <tr>
                    <th>Name</th>
                    <th>Total</th>
                    <th>Remaining</th>
                    <th>Used %</th>
                    <th>Tier</th>
                    <th>Reset</th>
                </tr>
            </thead>
            <tbody id="usageTableBody"></tbody>
        </table>
    </div>

    <script>
        const voiceContainer = document.getElementById("voiceContainer");
        const narratorSelect = document.getElementById("narrator-select");
        const usageTableBody = document.getElementById("usageTableBody");

        async function fetchVoices(apiKey) {
            try {
                voiceContainer.classList.remove("hidden");
                narratorSelect.innerHTML = ""; // Clear options
                const response = await fetch("https://api.elevenlabs.io/v1/voices", {
                    headers: { "xi-api-key": apiKey },
                });

                if (!response.ok) {
                    throw new Error(`Failed to fetch voices. Status: ${response.status}`);
                }

                const { voices } = await response.json();
                if (voices.length === 0) {
                    narratorSelect.innerHTML = `<option disabled>No voices found</option>`;
                    return;
                }

                voices.forEach((voice) => {
                    const option = document.createElement("option");
                    option.value = voice.voice_id;
                    option.textContent = `${voice.name} - ${voice.labels.gender || "Unknown"} - ${voice.labels.use_case || "General"}`;
                    narratorSelect.appendChild(option);
                });
            } catch (error) {
                console.error("Error fetching voices:", error);
                alert("An error occurred while fetching voices.");
            }
        }

        async function fetchAllApiUsage() {
            try {
                const apiData = await loadApis();
                for (const api of apiData.apis) {
                    const apiKey = api["xi-api-key"];
                    const name = api.name;

                    try {
                        const response = await fetch("https://api.elevenlabs.io/v1/user", {
                            headers: { "xi-api-key": apiKey },
                        });

                        if (!response.ok) {
                            throw new Error(`Failed to fetch usage for ${name}`);
                        }

                        const { subscription } = await response.json();
                        const total = subscription.character_limit;
                        const used = subscription.character_count;
                        const remaining = total - used;
                        const usagePercentage = ((used / total) * 100).toFixed(2);
                        const tier = subscription.tier;
                        const resetDate = new Date(subscription.next_character_count_reset_unix * 1000).toLocaleDateString();

                        const row = document.createElement("tr");
                        row.innerHTML = `
                            <td><button class="api-key-button" data-api-key="${apiKey}">${name}</button></td>
                            <td>${total.toLocaleString()}</td>
                            <td>${remaining.toLocaleString()}</td>
                            <td>${usagePercentage}%</td>
                            <td>${tier}</td>
                            <td>${resetDate}</td>
                        `;
                        usageTableBody.appendChild(row);
                    } catch (usageError) {
                        console.error(usageError.message);
                        const row = document.createElement("tr");
                        row.innerHTML = `
                            <td>${name}</td>
                            <td colspan="5" style="color: red;">Error fetching usage</td>
                        `;
                        usageTableBody.appendChild(row);
                    }
                }

                document.querySelectorAll(".api-key-button").forEach((button) => {
                    button.addEventListener("click", () => {
                        const apiKey = button.getAttribute("data-api-key");
                        fetchVoices(apiKey);
                    });
                });
            } catch (error) {
                console.error("Error loading API usage:", error);
                alert("An error occurred while loading API usage details.");
            }
        }

        async function loadApis() {
            const cachedData = localStorage.getItem("apiData");
            const cachedTime = localStorage.getItem("apiDataTime");
            const now = Date.now();

            if (cachedData && cachedTime && now - parseInt(cachedTime) < 1000) {
                return JSON.parse(cachedData);
            }

            try {
                const response = await fetch("APIs.json");
                const data = await response.json();
                localStorage.setItem("apiData", JSON.stringify(data));
                localStorage.setItem("apiDataTime", now.toString());
                return data;
            } catch (error) {
                console.error("Error fetching APIs.json:", error);
                throw error;
            }
        }

        window.addEventListener("load", fetchAllApiUsage);
    </script>
</body>
</html>
